==> ejc-front-impl-3.0.1-20220124.075036-98-sources.jar: com/ejianc/foundation/front/business/ide/controller/IdeTeamMgrController.java <==
package com.ejianc.foundation.front.business.ide.controller;

import java.util.List;
import java.util.Map;

import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.foundation.front.business.ide.service.IdeTeamService;
import com.ejianc.foundation.front.util.JsonBackData;
import com.ejianc.framework.core.exception.BusinessException;

@SuppressWarnings("deprecation")
@Controller
@RequestMapping(value = "ide/ideTeamMgr")
public class IdeTeamMgrController {
	
	@Autowired
	private IdeTeamService ideTeamService;
	
	@ResponseBody
	@RequestMapping(value = "showList" ,method = RequestMethod.POST)
	public JsonBackData showList(@RequestBody Map<String, Object> query) {
		JsonBackData back = new JsonBackData();
		int pageNumber = (Integer) query.get("pageNumber");
		int pageSize = (Integer) query.get("pageSize");
		String searchText = (String) query.get("searchText");
		boolean isDelete = (boolean) query.get("isDelete");
		int prodType = ((Integer) query.get("prodType"))!= null?((Integer) query.get("prodType")):0;
		try {
			Pageable pageable = null;
			pageable = new PageRequest(pageNumber <= 0 ? 0 :pageNumber, pageSize);
			back.setBackData(ideTeamService.findPage(searchText,prodType,isDelete,pageable));
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg("查询列表数据失败！");
		}
		return back;
	}
	@ResponseBody
	@RequestMapping(value = "showAllTeam")
	public JsonBackData showAllTeam() {
		JsonBackData back = new JsonBackData();
		try {
			back.setBackData(ideTeamService.findTeamByProdType(0));
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg("查询列表数据失败！");
		}
		return back;
	}
	
	@SuppressWarnings("unchecked")
	@ResponseBody
	@RequestMapping(value = "delete",method = RequestMethod.POST)
	public JsonBackData deleteByUrls(@RequestBody Map<String, Object> query){
		JsonBackData back = new JsonBackData();
		List<String> ids = (List<String>) query.get("ids");
		boolean isRemove = (boolean) query.get("isRemove");
		try {
			ideTeamService.deleteByIds(ids, isRemove);;
		} catch (BusinessException e) {
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		}
		return back;
	}
	
	@SuppressWarnings("unchecked")
	@ResponseBody
	@RequestMapping(value = "restore",method = RequestMethod.POST)
	public JsonBackData restoreByIds(@RequestBody Map<String, Object> query){
		JsonBackData back = new JsonBackData();
		List<String> ids = (List<String>) query.get("ids");
		try {
			ideTeamService.recoverByIds(ids);
		} catch (BusinessException e) {
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		}
		return back;
	}
}

==> ejc-front-impl-3.0.1-20250516.080027-190-sources.jar: com/ejianc/foundation/front/business/ide/controller/IdeTeamMgrController.java <==
package com.ejianc.foundation.front.business.ide.controller;

import java.util.ArrayList;
import java.util.List;
import java.util.Map;

import com.ejianc.foundation.front.business.ide.bo.IdeModuleBo;
import com.ejianc.foundation.front.business.ide.entity.IdeApp;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.data.domain.PageRequest;
import org.springframework.data.domain.Pageable;
import org.springframework.stereotype.Controller;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestMethod;
import org.springframework.web.bind.annotation.ResponseBody;

import com.ejianc.foundation.front.business.ide.service.IdeTeamService;
import com.ejianc.foundation.front.util.JsonBackData;
import com.ejianc.framework.core.exception.BusinessException;

@SuppressWarnings("deprecation")
@Controller
@RequestMapping(value = "ide/ideTeamMgr")
public class IdeTeamMgrController {
	
	@Autowired
	private IdeTeamService ideTeamService;
	
	@ResponseBody
	@RequestMapping(value = "showList" ,method = RequestMethod.POST)
	public JsonBackData showList(@RequestBody Map<String, Object> query) {
		JsonBackData back = new JsonBackData();
		int pageNumber = (Integer) query.get("pageNumber");
		int pageSize = (Integer) query.get("pageSize");
		String searchText = (String) query.get("searchText");
		boolean isDelete = (boolean) query.get("isDelete");
		int prodType = ((Integer) query.get("prodType"))!= null?((Integer) query.get("prodType")):0;
		try {
			Pageable pageable = null;
			pageable = new PageRequest(pageNumber <= 0 ? 0 :pageNumber, pageSize);
			back.setBackData(ideTeamService.findPage(searchText,prodType,isDelete,pageable));
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg("查询列表数据失败！");
		}
		return back;
	}
	@ResponseBody
	@RequestMapping(value = "showAllTeam")
	public JsonBackData showAllTeam() {
		JsonBackData back = new JsonBackData();
		try {
			back.setBackData(ideTeamService.findTeamByProdType(0));
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg("查询列表数据失败！");
		}
		return back;
	}

	/**
	 *
	 * 实施快速查询应用
	 *
	 * */
	@ResponseBody
	@RequestMapping(value = "searchApps" ,method = RequestMethod.GET)
	public List<IdeApp> searchApps(String searchText, Integer limit) {
		List<IdeApp> backData = new ArrayList<>();
		try {
			List<IdeModuleBo> moduleBos = ideTeamService.searchByAppName(searchText,limit);
			for(IdeModuleBo module :moduleBos){
				IdeApp app = new IdeApp();
				app.setId(Long.parseLong(module.getId()));
				app.setName(module.getTeamName()+"->"+module.getName());
				backData.add(app);
			}
		} catch (BusinessException e) {
			e.printStackTrace();
		}
		return backData;
	}

	@SuppressWarnings("unchecked")
	@ResponseBody
	@RequestMapping(value = "delete",method = RequestMethod.POST)
	public JsonBackData deleteByUrls(@RequestBody Map<String, Object> query){
		JsonBackData back = new JsonBackData();
		List<String> ids = (List<String>) query.get("ids");
		boolean isRemove = (boolean) query.get("isRemove");
		try {
			ideTeamService.deleteByIds(ids, isRemove);;
		} catch (BusinessException e) {
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		}
		return back;
	}
	
	@SuppressWarnings("unchecked")
	@ResponseBody
	@RequestMapping(value = "restore",method = RequestMethod.POST)
	public JsonBackData restoreByIds(@RequestBody Map<String, Object> query){
		JsonBackData back = new JsonBackData();
		List<String> ids = (List<String>) query.get("ids");
		try {
			ideTeamService.recoverByIds(ids);
		} catch (BusinessException e) {
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		} catch (Exception e) {
			e.printStackTrace();
			back.setSuccess(false);
			back.setBackMsg(e.getMessage());
		}
		return back;
	}
}
